<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Brothers Controller
 *
 * @property \App\Model\Table\BrothersTable $Brothers
 * @method \App\Model\Entity\Brother[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class BrothersController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Owners'],
        ];
        $brothers = $this->paginate($this->Brothers);

        $this->set(compact('brothers'));
    }

    /**
     * View method
     *
     * @param string|null $id Brother id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $brother = $this->Brothers->get($id, [
            'contain' => ['Owners'],
        ]);

        $this->set(compact('brother'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $brother = $this->Brothers->newEmptyEntity();
        if ($this->request->is('post')) {
            $brother = $this->Brothers->patchEntity($brother, $this->request->getData());
            if ($this->Brothers->save($brother)) {
                $this->Flash->success(__('The brother has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The brother could not be saved. Please, try again.'));
        }
        $owners = $this->Brothers->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('brother', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Brother id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $brother = $this->Brothers->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $brother = $this->Brothers->patchEntity($brother, $this->request->getData());
            if ($this->Brothers->save($brother)) {
                $this->Flash->success(__('The brother has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The brother could not be saved. Please, try again.'));
        }
        $owners = $this->Brothers->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('brother', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Brother id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $brother = $this->Brothers->get($id);
        if ($this->Brothers->delete($brother)) {
            $this->Flash->success(__('The brother has been deleted.'));
        } else {
            $this->Flash->error(__('The brother could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
