<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Daughters Controller
 *
 * @property \App\Model\Table\DaughtersTable $Daughters
 * @method \App\Model\Entity\Daughter[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class DaughtersController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Owners'],
        ];
        $daughters = $this->paginate($this->Daughters);

        $this->set(compact('daughters'));
    }

    /**
     * View method
     *
     * @param string|null $id Daughter id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $daughter = $this->Daughters->get($id, [
            'contain' => ['Owners'],
        ]);

        $this->set(compact('daughter'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $daughter = $this->Daughters->newEmptyEntity();
        if ($this->request->is('post')) {
            $daughter = $this->Daughters->patchEntity($daughter, $this->request->getData());
            if ($this->Daughters->save($daughter)) {
                $this->Flash->success(__('The daughter has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The daughter could not be saved. Please, try again.'));
        }
        $owners = $this->Daughters->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('daughter', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Daughter id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $daughter = $this->Daughters->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $daughter = $this->Daughters->patchEntity($daughter, $this->request->getData());
            if ($this->Daughters->save($daughter)) {
                $this->Flash->success(__('The daughter has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The daughter could not be saved. Please, try again.'));
        }
        $owners = $this->Daughters->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('daughter', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Daughter id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $daughter = $this->Daughters->get($id);
        if ($this->Daughters->delete($daughter)) {
            $this->Flash->success(__('The daughter has been deleted.'));
        } else {
            $this->Flash->error(__('The daughter could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
