<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * LandOwners Controller
 *
 * @property \App\Model\Table\LandOwnersTable $LandOwners
 * @method \App\Model\Entity\LandOwner[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class LandOwnersController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Lands', 'Owners'],
        ];
        $landOwners = $this->paginate($this->LandOwners);

        $this->set(compact('landOwners'));
    }

    /**
     * View method
     *
     * @param string|null $id Land Owner id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $landOwner = $this->LandOwners->get($id, [
            'contain' => ['Lands', 'Owners'],
        ]);

        $this->set(compact('landOwner'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $landOwner = $this->LandOwners->newEmptyEntity();
        if ($this->request->is('post')) {
            $landOwner = $this->LandOwners->patchEntity($landOwner, $this->request->getData());
            if ($this->LandOwners->save($landOwner)) {
                $this->Flash->success(__('The land owner has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The land owner could not be saved. Please, try again.'));
        }
        $lands = $this->LandOwners->Lands->find('list', ['limit' => 200])->all();
        $owners = $this->LandOwners->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('landOwner', 'lands', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Land Owner id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $landOwner = $this->LandOwners->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $landOwner = $this->LandOwners->patchEntity($landOwner, $this->request->getData());
            if ($this->LandOwners->save($landOwner)) {
                $this->Flash->success(__('The land owner has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The land owner could not be saved. Please, try again.'));
        }
        $lands = $this->LandOwners->Lands->find('list', ['limit' => 200])->all();
        $owners = $this->LandOwners->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('landOwner', 'lands', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Land Owner id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $landOwner = $this->LandOwners->get($id);
        if ($this->LandOwners->delete($landOwner)) {
            $this->Flash->success(__('The land owner has been deleted.'));
        } else {
            $this->Flash->error(__('The land owner could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
