<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Mouzas Controller
 *
 * @property \App\Model\Table\MouzasTable $Mouzas
 * @method \App\Model\Entity\Mouza[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class MouzasController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $mouzas = $this->paginate($this->Mouzas);

        $this->set(compact('mouzas'));
    }

    /**
     * View method
     *
     * @param string|null $id Mouza id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $mouza = $this->Mouzas->get($id, [
            'contain' => [],
        ]);

        $this->set(compact('mouza'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $mouza = $this->Mouzas->newEmptyEntity();
        if ($this->request->is('post')) {
            $mouza = $this->Mouzas->patchEntity($mouza, $this->request->getData());
            if ($this->Mouzas->save($mouza)) {
                $this->Flash->success(__('The mouza has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The mouza could not be saved. Please, try again.'));
        }
        $this->set(compact('mouza'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Mouza id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $mouza = $this->Mouzas->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $mouza = $this->Mouzas->patchEntity($mouza, $this->request->getData());
            if ($this->Mouzas->save($mouza)) {
                $this->Flash->success(__('The mouza has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The mouza could not be saved. Please, try again.'));
        }
        $this->set(compact('mouza'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Mouza id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $mouza = $this->Mouzas->get($id);
        if ($this->Mouzas->delete($mouza)) {
            $this->Flash->success(__('The mouza has been deleted.'));
        } else {
            $this->Flash->error(__('The mouza could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
