<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * OwnersSons Controller
 *
 * @property \App\Model\Table\OwnersSonsTable $OwnersSons
 * @method \App\Model\Entity\OwnersSon[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class OwnersSonsController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Owners'],
        ];
        $ownersSons = $this->paginate($this->OwnersSons);

        $this->set(compact('ownersSons'));
    }

    /**
     * View method
     *
     * @param string|null $id Owners Son id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $ownersSon = $this->OwnersSons->get($id, [
            'contain' => ['Owners'],
        ]);

        $this->set(compact('ownersSon'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $ownersSon = $this->OwnersSons->newEmptyEntity();
        if ($this->request->is('post')) {
            $ownersSon = $this->OwnersSons->patchEntity($ownersSon, $this->request->getData());
            if ($this->OwnersSons->save($ownersSon)) {
                $this->Flash->success(__('The owners son has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The owners son could not be saved. Please, try again.'));
        }
        $owners = $this->OwnersSons->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('ownersSon', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Owners Son id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $ownersSon = $this->OwnersSons->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $ownersSon = $this->OwnersSons->patchEntity($ownersSon, $this->request->getData());
            if ($this->OwnersSons->save($ownersSon)) {
                $this->Flash->success(__('The owners son has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The owners son could not be saved. Please, try again.'));
        }
        $owners = $this->OwnersSons->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('ownersSon', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Owners Son id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $ownersSon = $this->OwnersSons->get($id);
        if ($this->OwnersSons->delete($ownersSon)) {
            $this->Flash->success(__('The owners son has been deleted.'));
        } else {
            $this->Flash->error(__('The owners son could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
