<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Owners Controller
 *
 * @property \App\Model\Table\OwnersTable $Owners
 * @method \App\Model\Entity\Owner[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class RelationsController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {


    }

    /**
     * View method
     *
     * @param string|null $id Owner id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $owner = $this->Owners->get($id, [
            'contain' => ['Brothers', 'Daughters', 'Sisters', 'Sons', 'Spouses'],
        ]);

        $this->set(compact('owner'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        if ($this->request->is('post')) {
            $postData = $this->request->getData();
            $postData['relations']['_ids'] = array_keys(array_filter($postData['relation']['_ids']));
            //pr($postData); exit();
            $msg = '';
            // add as owner if not present
            $exists = $this->fetchTable('Owners')->find()->where(['Owners.nid' => $postData['nid'] ])->first()?->toArray();
            //pr($exists);
            //exit();
            if (!isset($exists['id'])) {
                // Save GPT credits
                echo "adding";
                $tModel = $this->fetchTable('Owners');
                $entity = $tModel->newEmptyEntity();
                $entity = $tModel->patchEntity($entity, $postData);
                $newOwnerId = $tModel->save($entity);
                $ownerId = $newOwnerId->id;
                $msg .= 'New Owner has been created';
            }else{
                $ownerId = $exists['id'];
            }
            // create the relation if not present
            if ($ownerId) {
                foreach ($postData['relations']['_ids'] as $rel) {
                    $exists = $this->fetchTable('OwnersRelations')->find()->where(['parent_id' => $rel, 'owner_id' => $ownerId, 'relation_id' => $postData['relation_id'] ])->count();
                    if (!$exists) {
                        $postData['parent_id'] = $rel;
                        $postData['owner_id'] = $ownerId;
                        $tModel = $this->fetchTable('OwnersRelations');
                        $entity = $tModel->newEmptyEntity();
                        $entity = $tModel->patchEntity($entity, $postData);
                        $s = $tModel->save($entity);
                        $msg .= "New Relation has been created with $ownerId <br>";
                    }
                }
            }
            $this->Flash->success(__($msg));
            return $this->redirect(['action' => 'add']);
        }
        $owners = $this->fetchTable('Owners')->find()->select(['id', 'name'])->where()->all()->toArray();
        $relations = $this->fetchTable('Relations')->find()->select(['id', 'name'])->where()->all()->toArray();
        $relArr = [];
        foreach ($relations as $relation){
            $relArr[$relation->id] = $relation->name;
        }
        //pr($relArr); exit();
        $this->set(compact('owners', 'relArr'));

    }

    /**
     * Edit method
     *
     * @param string|null $id Owner id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $owner = $this->Owners->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $owner = $this->Owners->patchEntity($owner, $this->request->getData());
            if ($this->Owners->save($owner)) {
                $this->Flash->success(__('The owner has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The owner could not be saved. Please, try again.'));
        }
        $this->set(compact('owner'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Owner id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $owner = $this->Owners->get($id);
        if ($this->Owners->delete($owner)) {
            $this->Flash->success(__('The owner has been deleted.'));
        } else {
            $this->Flash->error(__('The owner could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
