<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Sisters Controller
 *
 * @property \App\Model\Table\SistersTable $Sisters
 * @method \App\Model\Entity\Sister[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class SistersController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Owners'],
        ];
        $sisters = $this->paginate($this->Sisters);

        $this->set(compact('sisters'));
    }

    /**
     * View method
     *
     * @param string|null $id Sister id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $sister = $this->Sisters->get($id, [
            'contain' => ['Owners'],
        ]);

        $this->set(compact('sister'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $sister = $this->Sisters->newEmptyEntity();
        if ($this->request->is('post')) {
            $sister = $this->Sisters->patchEntity($sister, $this->request->getData());
            if ($this->Sisters->save($sister)) {
                $this->Flash->success(__('The sister has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The sister could not be saved. Please, try again.'));
        }
        $owners = $this->Sisters->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('sister', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Sister id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $sister = $this->Sisters->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $sister = $this->Sisters->patchEntity($sister, $this->request->getData());
            if ($this->Sisters->save($sister)) {
                $this->Flash->success(__('The sister has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The sister could not be saved. Please, try again.'));
        }
        $owners = $this->Sisters->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('sister', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Sister id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $sister = $this->Sisters->get($id);
        if ($this->Sisters->delete($sister)) {
            $this->Flash->success(__('The sister has been deleted.'));
        } else {
            $this->Flash->error(__('The sister could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
