<?php
declare(strict_types=1);

namespace App\Controller;

/**
 * Sons Controller
 *
 * @property \App\Model\Table\SonsTable $Sons
 * @method \App\Model\Entity\Son[]|\Cake\Datasource\ResultSetInterface paginate($object = null, array $settings = [])
 */
class SonsController extends AppController
{
    /**
     * Index method
     *
     * @return \Cake\Http\Response|null|void Renders view
     */
    public function index()
    {
        $this->paginate = [
            'contain' => ['Owners'],
        ];
        $sons = $this->paginate($this->Sons);

        $this->set(compact('sons'));
    }

    /**
     * View method
     *
     * @param string|null $id Son id.
     * @return \Cake\Http\Response|null|void Renders view
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function view($id = null)
    {
        $son = $this->Sons->get($id, [
            'contain' => ['Owners'],
        ]);

        $this->set(compact('son'));
    }

    /**
     * Add method
     *
     * @return \Cake\Http\Response|null|void Redirects on successful add, renders view otherwise.
     */
    public function add()
    {
        $son = $this->Sons->newEmptyEntity();
        if ($this->request->is('post')) {
            $son = $this->Sons->patchEntity($son, $this->request->getData());
            if ($this->Sons->save($son)) {
                $this->Flash->success(__('The son has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The son could not be saved. Please, try again.'));
        }
        $owners = $this->Sons->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('son', 'owners'));
    }

    /**
     * Edit method
     *
     * @param string|null $id Son id.
     * @return \Cake\Http\Response|null|void Redirects on successful edit, renders view otherwise.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function edit($id = null)
    {
        $son = $this->Sons->get($id, [
            'contain' => [],
        ]);
        if ($this->request->is(['patch', 'post', 'put'])) {
            $son = $this->Sons->patchEntity($son, $this->request->getData());
            if ($this->Sons->save($son)) {
                $this->Flash->success(__('The son has been saved.'));

                return $this->redirect(['action' => 'index']);
            }
            $this->Flash->error(__('The son could not be saved. Please, try again.'));
        }
        $owners = $this->Sons->Owners->find('list', ['limit' => 200])->all();
        $this->set(compact('son', 'owners'));
    }

    /**
     * Delete method
     *
     * @param string|null $id Son id.
     * @return \Cake\Http\Response|null|void Redirects to index.
     * @throws \Cake\Datasource\Exception\RecordNotFoundException When record not found.
     */
    public function delete($id = null)
    {
        $this->request->allowMethod(['post', 'delete']);
        $son = $this->Sons->get($id);
        if ($this->Sons->delete($son)) {
            $this->Flash->success(__('The son has been deleted.'));
        } else {
            $this->Flash->error(__('The son could not be deleted. Please, try again.'));
        }

        return $this->redirect(['action' => 'index']);
    }
}
