<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * LandsOwners Model
 *
 * @property \App\Model\Table\LandsTable&\Cake\ORM\Association\BelongsTo $Lands
 * @property \App\Model\Table\OwnersTable&\Cake\ORM\Association\BelongsTo $Owners
 *
 * @method \App\Model\Entity\LandsOwner newEmptyEntity()
 * @method \App\Model\Entity\LandsOwner newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\LandsOwner[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\LandsOwner get($primaryKey, $options = [])
 * @method \App\Model\Entity\LandsOwner findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\LandsOwner patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\LandsOwner[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\LandsOwner|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\LandsOwner saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\LandsOwner[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\LandsOwner[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\LandsOwner[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\LandsOwner[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class LandsOwnersTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('lands_owners');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Lands', [
            'foreignKey' => 'land_id',
        ]);
        $this->belongsTo('Owners', [
            'foreignKey' => 'owner_id',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('land_id')
            ->allowEmptyString('land_id');

        $validator
            ->integer('owner_id')
            ->allowEmptyString('owner_id');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('land_id', 'Lands'), ['errorField' => 'land_id']);
        $rules->add($rules->existsIn('owner_id', 'Owners'), ['errorField' => 'owner_id']);

        return $rules;
    }
}
