<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Lands Model
 *
 * @property \App\Model\Table\MouzasTable&\Cake\ORM\Association\BelongsTo $Mouzas
 * @property \App\Model\Table\LandsDistributionsTable&\Cake\ORM\Association\HasMany $LandsDistributions
 * @property \App\Model\Table\OwnersTable&\Cake\ORM\Association\BelongsToMany $Owners
 *
 * @method \App\Model\Entity\Land newEmptyEntity()
 * @method \App\Model\Entity\Land newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\Land[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Land get($primaryKey, $options = [])
 * @method \App\Model\Entity\Land findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\Land patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Land[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\Land|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Land saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Land[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Land[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\Land[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Land[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 * @property \App\Model\Table\LandsOwnersTable&\Cake\ORM\Association\HasMany $LandsOwners
 */
class LandsTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('lands');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Mouzas', [
            'foreignKey' => 'mouza_id',
        ]);
        $this->hasMany('LandsDistributions', [
            'foreignKey' => 'land_id',
        ]);
        $this->belongsToMany('Owners', [
            'foreignKey' => 'land_id',
            'targetForeignKey' => 'owner_id',
            'joinTable' => 'lands_owners',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('mouza_id')
            ->allowEmptyString('mouza_id');

        $validator
            ->scalar('dolil_no')
            ->maxLength('dolil_no', 20)
            ->allowEmptyString('dolil_no');

        $validator
            ->scalar('serial_no')
            ->maxLength('serial_no', 10)
            ->allowEmptyString('serial_no');

        $validator
            ->scalar('daag_no_hal')
            ->maxLength('daag_no_hal', 200)
            ->allowEmptyString('daag_no_hal');

        $validator
            ->scalar('daag_no_old')
            ->maxLength('daag_no_old', 200)
            ->allowEmptyString('daag_no_old');

        $validator
            ->decimal('total_land')
            ->allowEmptyString('total_land');

        $validator
            ->decimal('kaate')
            ->allowEmptyString('kaate');

        $validator
            ->scalar('tax_ok')
            ->maxLength('tax_ok', 1)
            ->allowEmptyString('tax_ok');

        $validator
            ->scalar('khariz_ok')
            ->maxLength('khariz_ok', 1)
            ->allowEmptyString('khariz_ok');

        $validator
            ->scalar('khatian_no')
            ->maxLength('khatian_no', 255)
            ->allowEmptyString('khatian_no');

        $validator
            ->date('bought_date')
            ->allowEmptyDate('bought_date');

        $validator
            ->scalar('bought_year')
            ->maxLength('bought_year', 4)
            ->allowEmptyString('bought_year');

        $validator
            ->scalar('bought_from')
            ->allowEmptyString('bought_from');

        $validator
            ->scalar('seller_father_name')
            ->allowEmptyString('seller_father_name');

        $validator
            ->scalar('seller_address')
            ->allowEmptyString('seller_address');

        $validator
            ->decimal('amount')
            ->allowEmptyString('amount');

        $validator
            ->scalar('details')
            ->allowEmptyString('details');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('mouza_id', 'Mouzas'), ['errorField' => 'mouza_id']);

        return $rules;
    }
}
