<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * OwnersBrothers Model
 *
 * @property \App\Model\Table\OwnersTable&\Cake\ORM\Association\BelongsTo $Owners
 *
 * @method \App\Model\Entity\OwnersBrother newEmptyEntity()
 * @method \App\Model\Entity\OwnersBrother newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersBrother[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersBrother get($primaryKey, $options = [])
 * @method \App\Model\Entity\OwnersBrother findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\OwnersBrother patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersBrother[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersBrother|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersBrother saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersBrother[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersBrother[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersBrother[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersBrother[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class OwnersBrothersTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('owners_brothers');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Owners', [
            'foreignKey' => 'owner_id',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('owner_id')
            ->allowEmptyString('owner_id');

        $validator
            ->integer('brother_of')
            ->allowEmptyString('brother_of');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('owner_id', 'Owners'), ['errorField' => 'owner_id']);

        return $rules;
    }
}
