<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * OwnersRelations Model
 *
 * @property \App\Model\Table\OwnersTable&\Cake\ORM\Association\BelongsTo $Owners
 * @property \App\Model\Table\RelationsTable&\Cake\ORM\Association\BelongsTo $Relations
 *
 * @method \App\Model\Entity\OwnersRelation newEmptyEntity()
 * @method \App\Model\Entity\OwnersRelation newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersRelation[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersRelation get($primaryKey, $options = [])
 * @method \App\Model\Entity\OwnersRelation findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\OwnersRelation patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersRelation[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersRelation|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersRelation saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersRelation[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersRelation[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersRelation[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersRelation[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 * @property \App\Model\Table\OwnersRelationsTable&\Cake\ORM\Association\BelongsTo $ParentOwnersRelations
 * @property \App\Model\Table\OwnersRelationsTable&\Cake\ORM\Association\HasMany $ChildOwnersRelations
 */
class OwnersRelationsTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('owners_relations');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Owners', [
            'foreignKey' => 'owner_id',
        ]);
        $this->belongsTo('Relations', [
            'foreignKey' => 'relation_id',
        ]);
        $this->belongsTo('ParentOwnersRelations', [
            'className' => 'OwnersRelations',
            'foreignKey' => 'parent_id',
        ]);
        $this->hasMany('ChildOwnersRelations', [
            'className' => 'OwnersRelations',
            'foreignKey' => 'parent_id',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('owner_id')
            ->allowEmptyString('owner_id');

        $validator
            ->integer('relation_id')
            ->allowEmptyString('relation_id');

        $validator
            ->integer('parent_id')
            ->allowEmptyString('parent_id');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('owner_id', 'Owners'), ['errorField' => 'owner_id']);
        $rules->add($rules->existsIn('relation_id', 'Relations'), ['errorField' => 'relation_id']);
        //$rules->add($rules->existsIn('parent_id', 'ParentOwnersRelations'), ['errorField' => 'parent_id']);
        return $rules;
    }
}
