<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * OwnersSpouses Model
 *
 * @property \App\Model\Table\OwnersTable&\Cake\ORM\Association\BelongsTo $Owners
 *
 * @method \App\Model\Entity\OwnersSpouse newEmptyEntity()
 * @method \App\Model\Entity\OwnersSpouse newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersSpouse[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\OwnersSpouse get($primaryKey, $options = [])
 * @method \App\Model\Entity\OwnersSpouse findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\OwnersSpouse patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersSpouse[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\OwnersSpouse|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersSpouse saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\OwnersSpouse[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersSpouse[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersSpouse[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\OwnersSpouse[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class OwnersSpousesTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('owners_spouses');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Owners', [
            'foreignKey' => 'owner_id',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->integer('owner_id')
            ->allowEmptyString('owner_id');

        $validator
            ->integer('spouse_of')
            ->allowEmptyString('spouse_of');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules): RulesChecker
    {
        $rules->add($rules->existsIn('owner_id', 'Owners'), ['errorField' => 'owner_id']);

        return $rules;
    }
}
