<?php
declare(strict_types=1);

namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Owners Model
 *
 * @property \App\Model\Table\LandsDistributionsTable&\Cake\ORM\Association\HasMany $LandsDistributions
 * @property \App\Model\Table\OwnersBrothersTable&\Cake\ORM\Association\HasMany $OwnersBrothers
 * @property \App\Model\Table\OwnersDaughtersTable&\Cake\ORM\Association\HasMany $OwnersDaughters
 * @property \App\Model\Table\OwnersSistersTable&\Cake\ORM\Association\HasMany $OwnersSisters
 * @property \App\Model\Table\OwnersSonsTable&\Cake\ORM\Association\HasMany $OwnersSons
 * @property \App\Model\Table\OwnersSpousesTable&\Cake\ORM\Association\HasMany $OwnersSpouses
 * @property \App\Model\Table\LandsTable&\Cake\ORM\Association\BelongsToMany $Lands
 *
 * @method \App\Model\Entity\Owner newEmptyEntity()
 * @method \App\Model\Entity\Owner newEntity(array $data, array $options = [])
 * @method \App\Model\Entity\Owner[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Owner get($primaryKey, $options = [])
 * @method \App\Model\Entity\Owner findOrCreate($search, ?callable $callback = null, $options = [])
 * @method \App\Model\Entity\Owner patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Owner[] patchEntities(iterable $entities, array $data, array $options = [])
 * @method \App\Model\Entity\Owner|false save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Owner saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Owner[]|\Cake\Datasource\ResultSetInterface|false saveMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Owner[]|\Cake\Datasource\ResultSetInterface saveManyOrFail(iterable $entities, $options = [])
 * @method \App\Model\Entity\Owner[]|\Cake\Datasource\ResultSetInterface|false deleteMany(iterable $entities, $options = [])
 * @method \App\Model\Entity\Owner[]|\Cake\Datasource\ResultSetInterface deleteManyOrFail(iterable $entities, $options = [])
 */
class ParentsTable extends Table
{
    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config): void
    {
        parent::initialize($config);

        $this->setTable('owners');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->hasMany('LandsDistributions', [
            'foreignKey' => 'owner_id',
        ]);

        $this->belongsToMany('Lands', [
            'foreignKey' => 'owner_id',
            'targetForeignKey' => 'land_id',
            'joinTable' => 'lands_owners',
        ]);
        $this->belongsToMany('Relations', [
            'foreignKey' => 'owner_id',
            'targetForeignKey' => 'relation_id',
            'joinTable' => 'owners_relations',
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator): Validator
    {
        $validator
            ->scalar('name')
            ->maxLength('name', 100)
            ->allowEmptyString('name');

        $validator
            ->scalar('gender')
            ->maxLength('gender', 1)
            ->allowEmptyString('gender');

        $validator
            ->scalar('nid')
            ->maxLength('nid', 30)
            ->allowEmptyString('nid');

        $validator
            ->decimal('total_land')
            ->allowEmptyString('total_land');

        return $validator;
    }
}
